@@ -18,7 +18,7 @@ from linghelper import DTW,getSemanticRelatedness
 from praatinterface import PraatLoader
 
 if 'phonostats' in settings.INSTALLED_APPS:
-    from phonostats.utils import getNeighCount,getPhonotacticProb
+    from phonostats.utils import getNeighCount,getPhonotacticProb,guessStress
 
 if 'celex' in settings.INSTALLED_APPS:
     from celex.utils import lookupFreq,lookupCat,categorize_words
@@ -342,11 +342,13 @@ class WordType(models.Model):
     def __unicode__(self):
         return u'%s' % self.Label
 
-    def getUR(self):
-        return ";".join([unicode(s) for s in self.UR.all()])
-
-    def getStrUR(self):
-        return ' '.join([s.getStrTrans() for s in self.underlying_set.all()])
+    def getUR(self,stressed=False,blick_style=False):
+        t = ' '.join([s.getStrTrans() for s in self.underlying_set.all()])
+        if not stressed:
+            t = re.sub(r'\d',r'',t)
+        if blick_style:
+            t = re.sub(r'EL(\d?)',r'AH\1 L',t)
+        return t
 
     def getBaseDuration(self):
         return sum([x.getAverageDur() for x in self.UR.all()])
@@ -362,16 +364,15 @@ class WordType(models.Model):
         return self.StressVowel
 
     def figureStresses(self):
-        stresses = lookupStress(self.Label, 'IPHOD')
-        vows = self.UR.filter(Vowel=True)
-        for s in stresses:
-            if '1' in s and len(s) == len(vows):
-                for i in range(len(vows)):
-                    vows[i].Stressed = int(s[i])
-                    vows[i].save()
-                    if vows[i].Stressed == 1:
-                        self.StressVowel = str(vows[i].SegmentType)
-                        self.save()
+        guessed = guessStress(self.getUR(blick_style=True))
+        stresses = re.sub(r'\D',r'',guessed)
+        syls = self.UR.filter(Syllabic=True)
+        for i in range(len(syls)):
+            syls[i].Stressed = int(stressed[i])
+            syls[i].save()
+            if syls[i].Stressed == 1:
+                self.StressVowel = str(syls[i].SegmentType)
+                self.save()
 
 
 
